@@ -13,7 +13,7 @@ class Update:
         self.raw_data_=update_data
         self.message = update_data.get("new_message", {})
     @property
-    def text(self) -> str | None:
+    def text(self) -> Optional[str]:
         """text message / متن پیام"""
         return self._data['text'] if "text" in self._data else None
     @property
@@ -47,19 +47,19 @@ class Update:
     def is_edited(self):
         return self._data['is_edited']
     @property
-    def file(self) -> dict | None:
+    def file(self) -> Optional[dict]:
         """file / فایل"""
         return self._data['file'] if "file" in self._data else None
     @property
-    def file_id(self) -> str | None:
+    def file_id(self) -> Optional[str]:
         """file id / آیدی فایل"""
         return self._data['file']['file_id'] if "file" in self._data else None
     @property
-    def file_name(self) -> str | None:
+    def file_name(self) -> Optional[str]:
         """file name / اسم فایل"""
         return self._data['file']['file_name'] if "file" in self._data else None
     @property
-    def size_file(self) -> int | None:
+    def size_file(self) -> Optional[int]:
         """size file / سایز فایل"""
         return self._data['file']['size'] if "file" in self._data else None
     @property
@@ -70,11 +70,11 @@ class Update:
         else:
             return "text"
     @property
-    def button(self) -> dict | None:
+    def button(self) -> Optional[dict]:
         """data button clicked / اطلاعات دکمه کلیک شده"""
         return self._data['aux_data'] if "aux_data" in self._data else None
     @property
-    def button_id(self) -> str | None:
+    def button_id(self) -> Optional[str]:
         """button id clicked button / آیدی دکمه کلیک شده"""
         return self.button['button_id'] if self.button else None
 
@@ -85,20 +85,20 @@ class Update:
         return await self._client.get_chat(self.chat_id)
 
     @auto_async
-    async def reply(self, text: str,keypad = None) -> dict:
+    async def reply(self, text: str,keypad = None,auto_delete: Optional[int] = None) -> props:
         """reply text / ریپلای متن"""
         return await self._client.send_text(
-            text, self.chat_id, reply_to_message_id=self.message_id,inline_keypad=keypad
+            text, self.chat_id, reply_to_message_id=self.message_id,inline_keypad=keypad,auto_delete=auto_delete
         )
 
     @auto_async
-    async def reply_poll(self, question: str, options: list) -> props:
+    async def reply_poll(self, question: str, options: list,auto_delete: Optional[int] = None) -> props:
         """reply poll / ریپلای نظرسنجی"""
-        return await self._client.send_poll(self.chat_id, question, options)
+        return await self._client.send_poll(self.chat_id, question, options,auto_delete)
 
     @auto_async
     async def reply_contact(
-        self, first_name: str, phone_number: str, last_name: Union[str,str] = ""
+        self, first_name: str, phone_number: str, last_name: Union[str,str] = "",auto_delete: Optional[int] = None
     ) -> props:
         """reply contact / ریپلای مخاطب"""
         return await self._client.send_contact(
@@ -107,23 +107,25 @@ class Update:
             last_name,
             phone_number,
             reply_to_message_id=self.message_id,
+            auto_delete=auto_delete
         )
 
     @auto_async
-    async def reply_location(self, latitude: str, longitude: str) -> props:
+    async def reply_location(self, latitude: str, longitude: str,auto_delete: Optional[int] = None) -> props:
         """reply location / ریپلای موقعیت مکانی"""
         return await self._client.send_location(
-            self.chat_id, latitude, longitude, reply_to_message_id=self.message_id
+            self.chat_id, latitude, longitude, reply_to_message_id=self.message_id,auto_delete=auto_delete
         )
 
     @auto_async
     async def reply_file(
         self,
-        file: str | Path | bytes,
-        name_file: str,
+        file: Union[str , Path , bytes],
+        name_file: Optional[str] = None,
         text: Optional[str] = None,
         type_file: Literal["File", "Image", "Voice", "Music", "Gif","Video"] = "File",
         disable_notification: Optional[bool] = False,
+        auto_delete: Optional[int] = None
     ) -> props:
         """reply file / ریپلای فایل"""
         return await self._client.send_file(
@@ -134,86 +136,93 @@ class Update:
             self.message_id,
             type_file,
             disable_notification,
+            auto_delete
         )
 
     @auto_async
     async def reply_image(
         self,
-        image: str | Path | bytes,
-        name_file: str,
+        image: Union[str , Path , bytes],
+        name_file: Optional[str] = None,
         text: Optional[str] = None,
         disable_notification: Optional[bool] = False,
+        auto_delete: Optional[int] = None
     ) -> props:
         """reply image / رپیلای تصویر"""
         return await self._client.send_image(
-            self.chat_id, image, name_file, text, self.message_id, disable_notification
+            self.chat_id, image, name_file, text, self.message_id, disable_notification,auto_delete
         )
 
     @auto_async
     async def reply_voice(
         self,
-        voice: str | Path | bytes,
-        name_file: str,
+        voice: Union[str , Path , bytes],
+        name_file: Optional[str] = None,
         text: Optional[str] = None,
         disable_notification: Optional[bool] = False,
+        auto_delete: Optional[int] = None
     ) -> props:
         """reply voice / رپیلای ویس"""
         return await self._client.send_voice(
-            self.chat_id, voice, name_file, text, self.message_id, disable_notification
+            self.chat_id, voice, name_file, text, self.message_id, disable_notification,auto_delete
         )
 
     @auto_async
     async def reply_music(
         self,
-        music: str | Path | bytes,
-        name_file: str,
+        music: Union[str , Path , bytes],
+        name_file: Optional[str] = None,
         text: Optional[str] = None,
         disable_notification: Optional[bool] = False,
+        auto_delete: Optional[int] = None
     ) -> props:
         """reply voice / رپیلای موزیک"""
         return await self._client.send_music(
-            self.chat_id, music, name_file, text, self.message_id, disable_notification
+            self.chat_id, music, name_file, text, self.message_id, disable_notification,auto_delete
         )
 
     @auto_async
     async def reply_gif(
         self,
-        gif: str | Path | bytes,
-        name_file: str,
+        gif: Union[str , Path , bytes],
+        name_file: Optional[str] = None,
         text: Optional[str] = None,
         disable_notification: Optional[bool] = False,
+        auto_delete: Optional[int] = None
     ) -> props:
         """reply voice / رپیلای گیف"""
         return await self._client.send_gif(
-            self.chat_id, gif, name_file, text, self.message_id, disable_notification
+            self.chat_id, gif, name_file, text, self.message_id, disable_notification,auto_delete
         )
 
     @auto_async
     async def reply_video(
         self,
-        video: str | Path | bytes,
-        name_file: str,
+        video: Union[str , Path , bytes],
+        name_file: Optional[str] = None,
         text: Optional[str] = None,
         disable_notification: Optional[bool] = False,
+        auto_delete: Optional[int] = None
     ) -> props:
         """reply voice / رپیلای ویدیو"""
         return await self._client.send_video(
-            self.chat_id, video, name_file, text, self.message_id, disable_notification
+            self.chat_id, video, name_file, text, self.message_id, disable_notification,auto_delete
         )
 
     @auto_async
     async def forward(
             self,
-            to_chat_id:str
+            to_chat_id:str,
+            auto_delete: Optional[int] = None
     ) -> props:
         """forward / فوروارد"""
-        return await self._client.forward_message(self.chat_id,self.message_id,to_chat_id)
+        return await self._client.forward_message(self.chat_id,self.message_id,to_chat_id,auto_delete=auto_delete)
 
     @auto_async
     async def download(
             self,
             path : Union[str,str] = "file"
-    ) -> dict | None:
+    ) -> Optional[dict]:
         """download / دانلود"""
         if self.file_id:
             return await self._client.download_file(self.file_id,path)
@@ -237,8 +246,9 @@ class Update:
 
 
 class UpdateButton:
-    def __init__(self, data: dict):
+    def __init__(self, data: dict,client: "Client"):
         self._data = data
+        self._client = client
 
     @property
     def raw_data(self) -> dict:
@@ -269,5 +279,146 @@ class UpdateButton:
         """text for button clicked / متن دکمه شیشه ای که روی آن کلیک شده"""
         return self._data["inline_message"]["text"]
 
+    @auto_async
+    async def send_text(self,text:str,keypad=None,auto_delete: Optional[int] = None,reply_to_message_id: Optional[str] = None):
+        return await self._client.send_text(
+            text, self.chat_id,inline_keypad=keypad,auto_delete=auto_delete,reply_to_message_id=reply_to_message_id
+        )
+
+    @auto_async
+    async def send_pool(self,question: str,options : list,auto_delete: Optional[int] = None):
+        return await self._client.send_poll(
+            self.chat_id,question,options,auto_delete
+        )
+
+    @auto_async
+    async def send_contact(
+        self,
+        first_name: str,
+        last_name: str,
+        phone_number: str,
+        auto_delete: Optional[int] = None,
+        reply_to_message_id: Optional[str] = None
+    ):
+        return await self._client.send_contact(
+            self.chat_id,first_name,last_name,phone_number,auto_delete=auto_delete,reply_to_message_id=reply_to_message_id
+        )
+
+    @auto_async
+    async def send_location(
+        self,
+        latitude: str,
+        longitude: str,
+        auto_delete: Optional[int] = None,
+        reply_to_message_id: Optional[str] = None
+    ):
+        return await self._client.send_location(
+            self.chat_id,latitude,longitude,auto_delete=auto_delete,reply_to_message_id=reply_to_message_id
+        )
+
+    @auto_async
+    async def send_file(
+        self,
+        file: Union[str , Path , bytes],
+        name_file: Optional[str] = None,
+        text: Optional[str] = None,
+        type_file: Literal['File', 'Image', 'Voice', 'Music', 'Gif', 'Video'] = "File",
+        auto_delete: Optional[int] = None,
+        reply_to_message_id: Optional[str] = None
+    ):
+        return await self._client.send_file(
+            self.chat_id,file,name_file,text,type_file=type_file,auto_delete=auto_delete,reply_to_message_id=reply_to_message_id
+        )
+
+    @auto_async
+    async def send_image(
+        self,
+        image: Union[str , Path , bytes],
+        name_file: Optional[str] = None,
+        text: Optional[str] = None,
+        auto_delete: Optional[int] = None,
+        reply_to_message_id: Optional[str] = None
+    ):
+        return await self._client.send_image(
+            self.chat_id,
+            image,
+            name_file,
+            text,
+            auto_delete=auto_delete,
+            reply_to_message_id=reply_to_message_id
+        )
+
+    @auto_async
+    async def send_video(
+        self,
+        video: Union[str , Path , bytes],
+        name_file: Optional[str] = None,
+        text: Optional[str] = None,
+        auto_delete: Optional[int] = None,
+        reply_to_message_id: Optional[str] = None
+    ):
+        return await self._client.send_video(
+            self.chat_id,
+            video,
+            name_file,
+            text,
+            auto_delete=auto_delete,
+            reply_to_message_id=reply_to_message_id
+        )
+
+    @auto_async
+    async def send_voice(
+        self,
+        voice: Union[str , Path , bytes],
+        name_file: Optional[str] = None,
+        text: Optional[str] = None,
+        auto_delete: Optional[int] = None,
+        reply_to_message_id: Optional[str] = None
+    ):
+        return await self._client.send_voice(
+            self.chat_id,
+            voice,
+            name_file,
+            text,
+            auto_delete=auto_delete,
+            reply_to_message_id=reply_to_message_id
+        )
+
+    @auto_async
+    async def send_music(
+        self,
+        music: Union[str , Path , bytes],
+        name_file: Optional[str] = None,
+        text: Optional[str] = None,
+        auto_delete: Optional[int] = None,
+        reply_to_message_id: Optional[str] = None
+    ):
+        return await self._client.send_music(
+            self.chat_id,
+            music,
+            name_file,
+            text,
+            auto_delete=auto_delete,
+            reply_to_message_id=reply_to_message_id
+        )
+
+    @auto_async
+    async def send_gif(
+        self,
+        gif: Union[str , Path , bytes],
+        name_file: Optional[str] = None,
+        text: Optional[str] = None,
+        auto_delete: Optional[int] = None,
+        reply_to_message_id: Optional[str] = None
+    ):
+        return await self._client.send_gif(
+            self.chat_id,
+            gif,
+            name_file,
+            text,
+            auto_delete=auto_delete,
+            reply_to_message_id=reply_to_message_id
+        )
+
     def __str__(self):
         return str(self._data)
\ No newline at end of file
